
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.21.0rc1',
    'branch_nick': 'feature-0-Documentations__1_21_0rc1_release_notes',
    'revision_id': '96a0b1ce2bc3eb4dd1d909e13789ea00a42b2e81',
    'revno': 8921
}
